@@ -109,9 +109,9 @@ nor Gnuplot is not recognized by maxima"))))
 ;;; SBCL.
 ;;; by yasuaki honda
 #-sbcl
-(if (not (fboundp (find-symbol "PRINT-INVERT-CASE" :maxima)))
-    (defun print-invert-case (obj)
-      (princ-to-string obj)))
+(unless (fboundp 'maxima::print-invert-case)
+  (defun print-invert-case (obj)
+    (princ-to-string obj)))
 
 (defun print-case-sensitive (obj)
   (if obj
@@ -126,7 +126,7 @@ nor Gnuplot is not recognized by maxima"))))
 
 (defun main-prompt ()
   (format () (concatenate 'string (string (code-char 3)) "(~A~D) " (string (code-char 4)))
-    (STRIPDOLLAR (print-case-sensitive $inchar)) $linenum))
+    (stripdollar (print-case-sensitive $inchar)) $linenum))
 
 (defun break-dbm-loop (at)
   (let* (
@@ -498,7 +498,7 @@ nor Gnuplot is not recognized by maxima"))))
 
 (defun tex-mtext (x l r) (tex-list (cdr x) l r ""))
 
-(defun tex-mlable (x l r)
+(defun tex-mlabel (x l r)
   (tex (caddr x)
     (append l
       (if (cadr x)
@@ -517,7 +517,7 @@ nor Gnuplot is not recognized by maxima"))))
 (defun latex (x)
 ;  (princ x)  ;; uncomment to debug.
   (if (and (listp x) (car x) (listp (car x)) (caar x)
-	   (equal (caar x) 'mlable)
+	   (equal (caar x) 'mlabel)
 	   (cdr x)
 	   (cadr x)
 	   (input-label-p (cadr x)))
