@@ -44,8 +44,9 @@ set plot3dOptions {
     {saturation 0.7 "Default saturation value."}
     {value 0.8 "Default brightness value."}
     {colorrange 0.5 "Range of colors used."}
+    {gradlist {{0 "#00ff00"} {1 "#ff00ff"}} "Color gradient: List of values and colors."}
     {ncolors 180 "Number of colors used."}
-    {colorscheme "hue" "Coloring Scheme (hue, saturation, value, gray or 0)."}
+    {colorscheme "hue" "Coloring Scheme (hue, saturation, value, gray, gradient or 0)."}
     {mesh_lines "black" "Color for the meshes outline, or 0 for no outline."}
 }
 
@@ -237,18 +238,14 @@ proc drawOval { c radius args } {
     set y [lindex $args [expr {$ll -1}]]
     set rest [lrange $args 0 [expr {$ll -3}]]
     set com [concat $c create oval [expr {$x - $radius}]  [expr {$y - $radius}] [expr {$x + $radius}]  [expr {$y + $radius}] $rest]
-    eval $com
-}
+    eval $com}
 
 proc plot3dcolorFun {win z } {
-    makeLocal $win zmin zmax ncolors hue saturation value colorrange colorscheme
-    if { $z < $zmin || $z > $zmax } {
-	return "none"
-    }
+    makeLocal $win zmin zmax ncolors hue saturation value colorrange colorscheme gradlist
+    if { $z < $zmin || $z > $zmax } {return "none"}
     set h [expr { 360*$hue }]
     if { ($value > 1) || ($value < 0) } {
-	set value [expr { $value - floor($value) }]
-    }
+        set value [expr { $value - floor($value) }]}
     set tem [expr {(double($colorrange)/$ncolors)*round(($z - $zmin)*$ncolors/($zmax - $zmin+.001))}]
     switch -exact $colorscheme {
 	"hue" { return [hsv2rgb [expr { 360*$tem+$h }] $saturation $value] }
@@ -256,9 +253,16 @@ proc plot3dcolorFun {win z } {
 	"value" { return [hsv2rgb $h $saturation [expr {$tem+$value}]] }
 	"gray"  { set g [expr { round( ($tem+$value)*255 ) } ]
 	    return  [format "\#%02x%02x%02x" $g $g $g] }
-	"0" { return "#ffffff" }
-    }
-}
+        "gradient" {
+            for {set i 0} {$i < [llength $gradlist]} {incr i} {
+                if {$tem < [lindex $gradlist $i 0]} break}
+            if {$i == 0} {
+                return [lindex $gradlist 0 1]
+            }
+            set down [lindex $gradlist [expr $i-1] 0]
+            set up [lindex $gradlist $i 0]
+            return [interpolatecolor [lindex $gradlist [expr $i-1] 1] [lindex $gradlist $i 1] [expr {($tem-$down)/($up-$down)}]]}
+	"0" { return "#ffffff" }}}
 
 proc setupPlot3dColors { win first_mesh} {
     upvar #0 [oarray $win] wvar
