@@ -6,7 +6,8 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (in-package :maxima)
-(declare-top (unspecial p y)) 
+
+(declare-top (unspecial p y))
 
 ;;   These functions can be used to keep an alphabetical masterlist in
 ;;*genvar* and *varlist* and use them.  I think *genpairs* is now
@@ -40,32 +41,15 @@
 ;;functions to change would be the functions which change the
 ;;NPOLYNOMIALS back to the polynomials and vice versa.
 
-;;    We have implemented a temporary storage area
-;;*TEMPORARY-POLYNOMIAL-AREA* which will be the default cons area inside
-;;various functions and their recursive subcalls.  We then copy to
-;;WORKING-STORAGE-AREA the result of the function.  Meanwhile the
-;;process POLYNOMIAL-AREA reclaims the temporary area when *SAFE* and it
-;;contains too much.  When *CHANGE-DEFAULT-CONS*  we use the temporary
-;;area in functions inside the body of (WITH-POLYNOMIAL-AREA ( form1
-;;form2 ..) body) The body is put in a PROGN and its final result as
-;;well as FORM1 FORM2..  copied into WORKING-STORAGE-AREA.  Then *safe*
-;;is reset to true.  We have also arranged so the debugger rebinds
-;;default-cons-area so that we won't create things in the wrong area
-;;while inside it.
-
 ;;the following are faster than the previous ones in the ratmac
 
-;(defvar *safe* nil)
-
-
-(defun safe-putprop ( sym value indicator &aux #+lispm(working-storage-area default-cons-area))
+(defun safe-putprop ( sym value indicator)
   (putprop sym value indicator))
+
 ;;(defun POINTERGP (A B) (> (VALGET A) (VALGET B)))
 ;;as a subst it is faster any problems 'wfs
-;#+lispm
-;(defsubst POINTERGP (A B) (> (VALGET A) (VALGET B)))
 
-(defun new-prep1 (x &aux temp) 
+(defun new-prep1 (x &aux temp)
        (cond ((floatp x)
 	      (cond ($keepfloat (cons x 1.0)) ((prepfloat x))))
 	     ((integerp x) (cons (cmod x) 1))
@@ -80,11 +64,11 @@
 	     ((and $ratfac (assolike x genpairs)))
 	     ((eq (caar x) 'mplus)
 	      (cond ($ratfac
-		     (setq x (mapcar 'new-prep1 (cdr x)))
-		     (cond ((andmapc 'frpoly? x)
+		     (setq x (mapcar #'new-prep1 (cdr x)))
+		     (cond ((every #'frpoly? x)
 			    (cons (mfacpplus (mapl #'(lambda (x)
 						      (rplaca x (caar x)))
-						  x)) 
+						  x))
 				  1))
 			   (t (do ((a (car x) (facrplus a (car l)))
 				   (l (cdr x) (cdr l)))
@@ -96,7 +80,7 @@
 	      (do ((a (savefactors (new-prep1 (cadr x)))
 		      (rattimes a (savefactors (new-prep1 (car l))) sw))
 		   (l (cddr x) (cdr l))
-		   (sw (not (and $norepeat (memq 'ratsimp (cdar x))))))
+		   (sw (not (and $norepeat (member 'ratsimp (cdar x) :test #'eq)))))
 		  ((null l) a)))
 	     ((eq (caar x) 'mexpt)
 	      (newvarmexpt x (caddr x) t))
@@ -110,7 +94,7 @@
 		    (t (cons (cadr x) (caddr x)))))
 	     ((eq (caar x) 'bigfloat)(bigfloat2rat x))
 	     ((eq (caar x) 'mrat)
-	      (cond ((and *withinratf* (memq 'trunc (car x)))
+	      (cond ((and *withinratf* (member 'trunc (car x) :test #'eq))
 		     (throw 'ratf nil))
 		    ((catch 'compatvl
 		       (progn (setq temp (compatvarl (caddar x)
@@ -118,7 +102,7 @@
 						     (cadddr (car x))
 						     genvar))
 			      t))
-		     (cond ((memq 'trunc (car x))
+		     (cond ((member 'trunc (car x) :test #'eq)
 			    (cdr ($taytorat x)))
 			   ((and (not $keepfloat)
 				 (or (pfloatp (cadr x)) (pfloatp (cddr x))))
@@ -133,33 +117,8 @@
 
 ;;because symbolics will assign a common lisp print name only when the symbol is referred to
 (defun safe-string (symb)
-  (let (#+lispm (default-cons-area working-storage-area))
+  (let ()
     (string symb)))
-#+symbolics
-(defun check-pnames ( &aux *exceptions*)
-  (declare (special *exceptions*))
-  (mapatoms #'(lambda (at &aux tem name)
-		(declare (special *exceptions*))
-		(cond (
-		       (setq tem (get at 'scl::print-name))
-		       (cond ((or (not (stringp tem))
-				  (eql (%area-number tem) *temporary-polynomial-area*)
-				  (not (eql (string-length tem)
-					    (array-total-size
-					     (setq name
-						   (symbol-name at)))))
-				  (sloop for i from 0 below (string-length tem)
-					when (not (eql (aref tem i)
-						       (int-char (aref name i))))
-					do (return t)))
-			      (push (list at tem) *exceptions*))))))
-	    'maxima nil)
-  *exceptions*)
-#+symbolics
-(defun fix-pnames (lis)
-  (sloop for v in lis do (setf (get (car v) 'scl::print-name) (format nil "~A" (car v)))))
-
-
 
 (defun new-ratf (l &aux  genpairs)
     (prog (u *withinratf*)
@@ -185,42 +144,29 @@
   ;;the ratsetup is done in my-newvar1
     (xcons (new-prep1 x)
 	   (list* 'mrat 'simp *varlist* *genvar*
-		  		  (if (and (not (atom x)) (memq 'irreducible (cdar x)))
+		  		  (if (and (not (atom x)) (member 'irreducible (cdar x) :test #'eq))
 		      '(irreducible)))))
-	  
+
 (defun new-rat (x &aux genpairs)
   (cond
     ((polynomialp x) (cons x 1))
     ((rational-functionp x) x)
     ((and (listp x) (eq (caar x) 'mrat))
-	 (cond ((memq (car (num (cdr x))) *genvar*)
+	 (cond ((member (car (num (cdr x))) *genvar* :test #'eq)
 		(cdr x))
 	       (t (format t "~%disrepping")(new-rat  ($totaldisrep x)))))
-	(t 
-	     
+	(t
+
   (prog (u *withinratf*)
 	(setq *withinratf* t)
 	(cond ((mbagp x)(return (cons (car x) (mapcar 'new-rat (cdr x)))))
-	      (t 
+	      (t
 	(when (eq '%% (catch 'ratf (new-newvar x)))
 	  (setq *withinratf* nil)(return (srf x)))
 	(let ((varlist *varlist*)(genvar *genvar*))
 	  (setq u (catch 'ratf (new-prep1 x)))  ;;truncations
 	  (return (or u (prog2 (setq *withinratf* nil) (srf x)))))))))))
 
-;(defun my-newvar1 (x &aux caarx)
-;       (cond ((numberp x) nil)
-;	     ((assolike x genpairs) nil)
-;	     ((atom x) (add-newvar-to-genpairs x )nil)
-;	     ((memq (setq caarx (caar x))
-;		    '(mplus mtimes rat mdifference
-;			    mquotient mminus bigfloat mlist))
-;	      (mapc (function my-newvar1) (cdr x)))
-;	     (t (case caarx
-;		  (mexpt (my-newvar1 (second x)))
-;		  (mnctimes (add-newvar-to-genpairs x))
-;		  (mrat (ferror "how did you get here"))
-;		  (otherwise (ferror "What is x like"))))))
 
 (defun my-newvar1 (x)
        (cond ((numberp x) nil)
@@ -228,20 +174,20 @@
 	    ;;; ((memalike x varlist))we 're using *varlist*
 ;	;     ((memalike x vlist) nil)
 	     ((atom x) (add-newvar-to-genpairs x )nil)
-	     ((memq (caar x)
+	     ((member (caar x)
 		    '(mplus mtimes rat mdifference
-			    mquotient mminus bigfloat))
-	      (mapc (function my-newvar1) (cdr x)))
-	     
+			    mquotient mminus bigfloat) :test #'eq)
+	      (mapc #'my-newvar1 (cdr x)))
+
 	     ((eq (caar x) 'mexpt)
 	       (my-newvar1 (second  x) ))
 	     ;; ;(newvarmexpt x (caddr x) nil))
-	     ((eq (caar x) 'mrat)(ferror " how did you get here Bill?")
-	      (and *withinratf* (memq 'trunc (cdddar x)) (throw 'ratf '%%))
+	     ((eq (caar x) 'mrat) (merror " how did you get here Bill?")
+	      (and *withinratf* (member 'trunc (cdddar x) :test #'eq) (throw 'ratf '%%))
 	      (cond ($ratfac (mapc 'newvar3 (caddar x)))
-		    (t (mapc (function my-newvar1) (reverse (caddar x))))))
+		    (t (mapc #'my-newvar1 (reverse (caddar x))))))
 	     ((eq (caar x) 'mnctimes)(add-newvar-to-genpairs x ))
-	     (t (ferror "What is x like ? ~A" x))))
+	     (t (merror "What is x like ? ~A" x))))
 
 ;;need this?
 ;	      (cond (*fnewvarsw (setq x (littlefr1 x))
@@ -263,20 +209,15 @@
 ;;might be worthwhile to keep a resource or list of gensyms so that when
 ;;you reset-vgp then you don't just discard them you reuse them via the gensym call
 
-(defmacro with-working-storage-area(&body body)
-  `(let  (#+lispm(default-cons-area working-storage-area))
-    ,@ body))
- 
 (defvar *genvar-resemble* t)
 
-
 (defun add-newvar ( va &optional (use-*genpairs* t)&aux  the-gensym)
   "If va is not in varlist ADD-NEWVAR splices va into the varlist and a new gensym
 into genvar ordering and adds to genpairs"
  (declare (special $order_function))
    use-*genpairs*  ;;don't use it
-  (cond ((and (symbolp va) (not (eql (aref  (safe-string va) 0) #\$))) (ferror "doesn't begin with $")))
-  (let (#+lispm(default-cons-area working-storage-area))
+  (cond ((and (symbolp va) (not (eql (aref  (safe-string va) 0) #\$))) (merror "doesn't begin with $")))
+  (let ()
    (multiple-value-bind (after there)
        (find-in-ordered-list va *varlist* $order_function)
      (cond ((not there)
@@ -285,48 +226,43 @@ into genvar ordering and adds to genpairs"
 ;                   (setq the-gensym (make-symbol (string-trim "$" (safe-string va)))))
 ;		  (t
 ;		   (setq the-gensym (gensym))))
-	    #+lispm
-	    (setq va (new-copy-from-temporary-area va))
+
 	    (safe-putprop the-gensym va 'disrep)
 ;	    (cond (use-*genpairs* (push (cons va (rget the-gensym)) *genpairs*)))
 ;	    (rat-setup1 va the-gensym)(rat-setup2 va the-gensym)
-	    (with-working-storage-area
-	      (setq *genvar* (nsplice-in after the-gensym *genvar*))
-	      (setq *varlist* (nsplice-in after va  *varlist*)))
-    	    (cond ( *check-order*
+	    (setq *genvar* (nsplice-in after the-gensym *genvar*))
+	    (setq *varlist* (nsplice-in after va  *varlist*))
+    	    (when  *check-order*
 ;		   (check-repeats *varlist*)
-		   (check-order *varlist*)))
-	    (sloop for v in (nthcdr  (max 0 after) *genvar*)
-		  for i from  (f1+  after)
-		  do (set v i)))
-	   (there (setq the-gensym (nth after *genvar*))
-		  (cond ((not (nc-equal (get the-gensym 'disrep) va))
-			 (fsignal "bad-correspondence" )))))
+	      (check-order *varlist*))
+	    (loop for v in (nthcdr  (max 0 after) *genvar*)
+		  for i from  (1+ after)
+		  do (setf (symbol-value v) i)))
+	   (there
+	    (setq the-gensym (nth after *genvar*))
+	    (cond ((not (nc-equal (get the-gensym 'disrep) va))
+		   (fsignal "bad-correspondence" )))))
   (values the-gensym (not there)))))
 
-
-
-
 (defun rat-setup1 (v g)
   (and $ratwtlvl
-	        (setq v (assolike v *ratweights))
-	        (if v (safe-putprop g v '$ratweight) (remprop g '$ratweight))))
+       (setq v (assolike v *ratweights))
+       (if v (safe-putprop g v '$ratweight) (remprop g '$ratweight))))
 
 
 
 (defun rat-setup2 (v g)
   (when $algebraic
-		(cond ((setq v (algpget  v))
-		       (let (#+lispm(default-cons-area working-storage-area))
-		       (safe-putprop  g  v 'tellrat)))
-		      (t (remprop  g 'tellrat)))))
+    (cond ((setq v (algpget  v))
+	   (let ()
+	     (safe-putprop  g  v 'tellrat)))
+	  (t (remprop  g 'tellrat)))))
 
 
 
 (defun te (f g)
-    (let* ((genvar   (nreverse (sort (union1 (listovars f) (listovars g))
-		       #'pointergp)))
-	   (varlist (sloop for v in genvar collecting (get v 'disrep) )))
+    (let* ((genvar (nreverse (sort (union1 (listovars f) (listovars g)) #'pointergp)))
+	   (varlist (loop for v in genvar collecting (get v 'disrep))))
       (break t)
      (ratreduce  f g)))
 
@@ -338,11 +274,11 @@ into genvar ordering and adds to genpairs"
     (pfactor poly)))
 
 (defun multiply-factors-with-multiplicity (a-list &aux ( answer 1))
-  (sloop for v in a-list by 'cddr
-	for w in (cdr a-list) by 'cddr
-	do (sloop while (> w 0)
+  (loop for v in a-list by #'cddr
+	for w in (cdr a-list) by #'cddr
+	do (loop while (> w 0)
 		 do (setq answer (n* answer v))
-		 (setq w (f1- w))))
+		 (setq w (1- w))))
   answer)
 
 (defun copy-vgp ()
@@ -354,9 +290,9 @@ into genvar ordering and adds to genpairs"
 		      (t (aref f 0))))
 
 (defun ar-last (aray)
-  (aref aray (f1- (length (the cl:array aray)))))
+  (aref aray (1- (length (the cl:array aray)))))
 (defun ar-second-last (aray)
-  (aref aray (f- (length (the cl:array aray)) 2)))
+  (aref aray (- (length (the cl:array aray)) 2)))
 
 (defun set-fill-pointer (aray n)(setf (fill-pointer aray ) n) aray)
 (defun constant-term-in-main-variable (f)
@@ -366,323 +302,180 @@ into genvar ordering and adds to genpairs"
 
 #+debug
 (progn
-(defmfun pplus (x y)
-  (cond ((pcoefp x) (pcplus x y))
-	((pcoefp y) (pcplus y x))
-	((eq (p-var x) (p-var y))
-	 (psimp (p-var x) (pplus1 (p-terms y) (p-terms x))))
-	((pointergp (p-var x) (p-var y))
-	 (psimp (p-var x) (pcplus1 y (p-terms x))))
-	(t (psimp (p-var y) (pcplus1 x (p-terms y))))))
+  (defmfun pplus (x y)
+    (cond ((pcoefp x) (pcplus x y))
+	  ((pcoefp y) (pcplus y x))
+	  ((eq (p-var x) (p-var y))
+	   (psimp (p-var x) (ptptplus (p-terms y) (p-terms x))))
+	  ((pointergp (p-var x) (p-var y))
+	   (psimp (p-var x) (ptcplus y (p-terms x))))
+	  (t (psimp (p-var y) (ptcplus x (p-terms y))))))
 
-(defmfun ptimes (x y)
-  (cond ((pcoefp x) (if (pzerop x) 0 (pctimes x y)))
-	((pcoefp y) (if (pzerop y) 0 (pctimes y x)))
-	((eq (p-var x) (p-var y))
-	 (palgsimp (p-var x) (ptimes1 (p-terms x) (p-terms y)) (alg x)))
-	((pointergp (p-var x) (p-var y))
-	 (psimp (p-var x) (pctimes1 y (p-terms x))))
-	(t (psimp (p-var y) (pctimes1 x (p-terms y))))))
-(defun ptimes (x y)
+  (defmfun ptimes (x y)
+    (cond ((pcoefp x) (if (pzerop x) 0 (pctimes x y)))
+	  ((pcoefp y) (if (pzerop y) 0 (pctimes y x)))
+	  ((eq (p-var x) (p-var y))
+	   (palgsimp (p-var x) (ptimes1 (p-terms x) (p-terms y)) (alg x)))
+	  ((pointergp (p-var x) (p-var y))
+	   (psimp (p-var x) (pctimes1 y (p-terms x))))
+	  (t (psimp (p-var y) (pctimes1 x (p-terms y))))))
+  (defun ptimes (x y)
     (cond ((atom x)
-           (cond ((and (numberp x)
-                       (zerop x))
-                  0)
-                 (t (pctimes x y))))
-          ((atom y)
-           (cond ((and (numberp y)
-                       (zerop y))
-                  0)
-                 (t (pctimes y x))))
-          ((eq (car x) (car y))
-           (palgsimp (car x) (ptimes1 (cdr x) (cdr y)) (alg x)))
-          ((> (symbol-value (car x)) (symbol-value (car y)))
-           (psimp (car x) (pctimes1 y (cdr x))))
-          (t (psimp (car y) (pctimes1 x (cdr y))))))
+	   (cond ((and (numberp x)
+		       (zerop x))
+		  0)
+		 (t (pctimes x y))))
+	  ((atom y)
+	   (cond ((and (numberp y)
+		       (zerop y))
+		  0)
+		 (t (pctimes y x))))
+	  ((eq (car x) (car y))
+	   (palgsimp (car x) (ptimes1 (cdr x) (cdr y)) (alg x)))
+	  ((> (symbol-value (car x)) (symbol-value (car y)))
+	   (psimp (car x) (pctimes1 y (cdr x))))
+	  (t (psimp (car y) (pctimes1 x (cdr y))))))
 
-(defmfun pdifference (x y)
-  (cond ((pcoefp x) (pcdiffer x y))
-	((pcoefp y) (pcplus (cminus y) x))
-	((eq (p-var x) (p-var y))
-	 (psimp (p-var x) (pdiffer1 (p-terms x) (p-terms y))))
-	((pointergp (p-var x) (p-var y))
-	 (psimp (p-var x) (pcdiffer2 (p-terms x) y)))
-	(t (psimp (p-var y) (pcdiffer1 x (p-terms y))))))
+  (defmfun pdifference (x y)
+    (cond ((pcoefp x) (pcdiffer x y))
+	  ((pcoefp y) (pcplus (cminus y) x))
+	  ((eq (p-var x) (p-var y))
+	   (psimp (p-var x) (ptptdiffer (p-terms x) (p-terms y))))
+	  ((pointergp (p-var x) (p-var y))
+	   (psimp (p-var x) (ptcdiffer-minus (p-terms x) y)))
+	  (t (psimp (p-var y) (ptcdiffer x (p-terms y))))))
 
 
-(defun pfactor (p &aux ($algebraic algfac*))
-       (cond ((pcoefp p) (cfactor p))
-	     ($ratfac (pfacprod p))
-	     (t (setq p (factorout p))
-		(cond ((equal (cadr p) 1) (car p))
-		      ((numberp (cadr p)) (append (cfactor (cadr p)) (car p)))
-		      (t ((lambda (cont)
-		            (nconc
-			     (cond ((equal (car cont) 1) nil)
-				   (algfac*
-				    (cond (modulus (list (car cont) 1))
-					  ((equal (car cont) '(1 . 1)) nil)
-					  ((equal (cdar cont) 1)
-					   (list (caar cont) 1))
-					  (t (list (caar cont) 1 (cdar cont) -1))))
-				   (t (cfactor (car cont))))
-			     (pfactor11 (psqfr (cadr cont)))
-			     (car p)))
-			  (cond (modulus (list (leadalgcoef (cadr p))
-					       (monize (cadr p))))
-				(algfac* (algcontent (cadr p)))
+  (defun pfactor (p &aux ($algebraic algfac*))
+    (cond ((pcoefp p) (cfactor p))
+	  ($ratfac (pfacprod p))
+	  (t (setq p (factorout p))
+	     (cond ((equal (cadr p) 1) (car p))
+		   ((numberp (cadr p)) (append (cfactor (cadr p)) (car p)))
+		   (t ((lambda (cont)
+			 (nconc
+			  (cond ((equal (car cont) 1) nil)
+				(algfac*
+				 (cond (modulus (list (car cont) 1))
+				       ((equal (car cont) '(1 . 1)) nil)
+				       ((equal (cdar cont) 1)
+					(list (caar cont) 1))
+				       (t (list (caar cont) 1 (cdar cont) -1))))
+				(t (cfactor (car cont))))
+			  (pfactor11 (psqfr (cadr cont)))
+			  (car p)))
+		       (cond (modulus (list (leadalgcoef (cadr p))
+					    (monize (cadr p))))
+			     (algfac* (algcontent (cadr p)))
 
-				(t (pcontent (cadr p))))))))))
+			     (t (pcontent (cadr p))))))))))
 
 
-(defun fullratsimp (l)
- (let (($expop 0) ($expon 0) (inratsimp t) $ratsimpexpons)
-      (setq l ($totaldisrep l)) (fr1 l varlist)))    
-)
-
-#+lispm
-(progn
-(defun pplus (x y)
-  (with-polynomial-area ()
-      (cond ((pcoefp x) (pcplus x y))
-	((pcoefp y) (pcplus y x))
-	((eq (p-var x) (p-var y))
-	 (psimp (p-var x) (pplus1 (p-terms y) (p-terms x))))
-	((pointergp (p-var x) (p-var y))
-	 (psimp (p-var x) (pcplus1 y (p-terms x))))
-	(t (psimp (p-var y) (pcplus1 x (p-terms y)))))))
-
-(defun ptimes (x y)
-  (with-polynomial-area ()
-    (cond ((pcoefp x) (if (pzerop x) (pzero) (pctimes x y)))
-	       ((pcoefp y) (if (pzerop y) (pzero) (pctimes y x)))
-	       ((eq (p-var x) (p-var y))
-		(palgsimp (p-var x) (ptimes1 (p-terms x) (p-terms y)) (alg x)))
-	       ((pointergp (p-var x) (p-var y))
-		(psimp (p-var x) (pctimes1 y (p-terms x))))
-	       (t (psimp (p-var y) (pctimes1 x (p-terms y)))))))
-
-
-(defmfun pdifference (x y)
-  (with-polynomial-area ()
-  (cond ((pcoefp x) (pcdiffer x y))
-	((pcoefp y) (pcplus (cminus y) x))
-	((eq (p-var x) (p-var y))
-	 (psimp (p-var x) (pdiffer1 (p-terms x) (p-terms y))))
-	((pointergp (p-var x) (p-var y))
-	 (psimp (p-var x) (pcdiffer2 (p-terms x) y)))
-	(t (psimp (p-var y) (pcdiffer1 x (p-terms y)))))))
-
-
-(defun pfactor (p &aux ($algebraic algfac*))
-      (with-polynomial-area () (cond ((pcoefp p) (cfactor p))
-	     ($ratfac (pfacprod p))
-	     (t (setq p (factorout p))
-		(cond ((equal (cadr p) 1) (car p))
-		      ((numberp (cadr p)) (append (cfactor (cadr p)) (car p)))
-		      (t ((lambda (cont)
-		            (nconc
-			     (cond ((equal (car cont) 1) nil)
-				   (algfac*
-				    (cond (modulus (list (car cont) 1))
-					  ((equal (car cont) '(1 . 1)) nil)
-					  ((equal (cdar cont) 1)
-					   (list (caar cont) 1))
-					  (t (list (caar cont) 1 (cdar cont) -1))))
-				   (t (cfactor (car cont))))
-			     (pfactor11 (psqfr (cadr cont)))
-			     (car p)))
-			  (cond (modulus (list (leadalgcoef (cadr p))
-					       (monize (cadr p))))
-				(algfac* (algcontent (cadr p)))
-				(t (pcontent (cadr p)))))))))))
-
-;;timings of factoring (x+y+z)^10
-;;on explorer feb 2 microcode ?? 6.6sec
-;;on 3600     feb 10 rel60d microcode 313 5.1 sec maxima 2.6
-    ;;;(tried loading all the new compiled files) and it was 4.6sec
-;;on 3600     feb 10 microcode 315 4.45 seconds 
-
-;;timings of factoring (x+y+z)^20
-;;3600 rel6 betaII mic.315 20.7 seconds
-
-
-(defmfun $factor (&rest args)
-  (check-arg args (and (listp args)(memq (length args) '( 1 2))) "one or two args")
-  (with-polynomial-area-new ()
-    :reset
-  (let ($intfaclim (varlist (cdr $ratvars)) genvar ans)
-    (setq ans (apply #'factor args))
-    (if (and factorresimp $negdistrib
-	     (mtimesp ans) (null (cdddr ans))
-	     (equal (cadr ans) -1) (mplusp (caddr ans)))
-	(let (($expop 0) ($expon 0)) ($multthru ans))
-	ans))) )
-
-
-(defmfun ratreduce (x y &aux b)
-  (with-polynomial-area ()
-  (cond ((pzerop y) (errrjf "QUOTIENT by ZERO"))
-	((pzerop x) (rzero))
-	((eqn y 1) (cons x 1))
-	((and $keepfloat (pcoefp y) (or $float (floatp y) (pfloatp x)))
-	 (cons (pctimes (quotient 1.0 y) x) 1))
-	(t (setq b (pgcdcofacts x y))
-	   (setq b (ratalgdenom (rplacd (cdr b) (caddr b))))
-	   (cond ((and modulus (pcoefp (cdr b)))
-		  (cons (pctimes (crecip (cdr b)) (car b)) 1))
-		 ((pminusp (cdr b))
-		  (cons (pminus (car b)) (pminus (cdr b))))
-		 (t b))))))
-
-
-(defmfun ratquotient (x y)
-  (with-polynomial-area ()
-    (rattimes x (ratinvert y) t)) )
-
-
-
-(defun fullratsimp (l)
-  (with-polynomial-area ()
+  (defun fullratsimp (l)
     (let (($expop 0) ($expon 0) (inratsimp t) $ratsimpexpons)
-	     (setq l ($totaldisrep l)) (fr1 l varlist))))
-
-(defun fullratsimp (l)
-  (with-polynomial-area ()
-    (let (($expop 0) ($expon 0) (inratsimp t) $ratsimpexpons)
-      (cond ((mbagp l)(cons (car l) (mapcar  #'fullratsimp (cdr l))))
-	    (t 
-	     (setq l ($totaldisrep l)) (fr1 l varlist))) )))
-
-
-(defmfun $trigreduce n
- (let ((*trigred t) (*noexpand t) var $trigexpand $verbose $ratprint)
- (declare (special *trigred *noexpand $trigexpand $verbose $ratprint ans var $verbose))   
-      (cond ((= n 2) (setq var (arg 2)))
-	    ((= n 1) (setq var '*novar))
-	    (t (merror "wrong number of args to TRIGREDUCE")))
-     (with-polynomial-area ()
-      (gcdred (sp1 (arg 1))))))
-
-)
+      (setq l ($totaldisrep l)) (fr1 l varlist))))
 
 
 ;;the following works but is slow see projective
 (defmfun $gcdlist (&rest fns)
   (cond ((and (eq (length fns) 1)
-	      ($listp (car fns))(setq fns (cdr (car fns))))))
-  (let  ( varlist  gcd-denom gcd-num rat-fns )
-	(cond ((eq (length fns) 1) (car fns))
-	      (t
-	       (sloop for v in fns
-		     do (newvar v))
-	  (with-polynomial-area ()
-	      (setq rat-fns (sloop for v in fns
-		     collecting (cdr (ratrep* v))))
-	      (setq gcd-num (num (car rat-fns)))
-	      (sloop for w in (cdr rat-fns)
-		    do
-		    (setq gcd-num (pgcd gcd-num (num  w))))
-	      (setq gcd-denom (denom (car rat-fns)))
-	      (sloop for w in (cdr rat-fns)
-		    do (setq gcd-denom (pgcd gcd-denom (denom w))))
-	      (ratdisrep (cons (list 'mrat 'simp varlist genvar)
-			       (cons gcd-num gcd-denom))))))))
-
+	      ($listp (car fns))
+	      (setq fns (cdr (car fns))))))
+  (let (varlist  gcd-denom gcd-num rat-fns )
+    (cond ((eq (length fns) 1) (car fns))
+	  (t
+	   (loop for v in fns
+	      do (newvar v))
+	   (setq rat-fns (loop for v in fns	collecting (cdr (ratrep* v))))
+	   (setq gcd-num (num (car rat-fns)))
+	   (loop for w in (cdr rat-fns)
+	      do
+	      (setq gcd-num (pgcd gcd-num (num  w))))
+	   (setq gcd-denom (denom (car rat-fns)))
+	   (loop for w in (cdr rat-fns)
+	      do (setq gcd-denom (pgcd gcd-denom (denom w))))
+	   (ratdisrep (cons (list 'mrat 'simp varlist genvar)
+			    (cons gcd-num gcd-denom)))))))
 
 ;;;;the following works but seems slower than factoring
 ;(defun $projective ( vector)
 ;  (check-arg vector '$listp nil)
 ;  (let  ( VARLIST  (fns (cdr vector))
 ;			answer gcd-num factor lcm-denom  rat-fns )
-;	       (sloop for v in fns
+;	       (loop for v in fns
 ;		     do (newvar v))
-;	  (with-polynomial-area ()
-;	      (setq rat-fns (sloop for v in fns
+;	      (setq rat-fns (loop for v in fns
 ;		     collecting (cdr (ratrep* v))))
 ;	      (setq gcd-num (num (car rat-fns)))
-;	      (sloop for w in (cdr rat-fns)
+;	      (loop for w in (cdr rat-fns)
 ;		    do
 ;		    (setq gcd-num (pgcd gcd-num (num  w))))
 ;	      (setq lcm-denom (denom (car rat-fns)))
-;	      (sloop for w in (cdr rat-fns)
+;	      (loop for w in (cdr rat-fns)
 ;		    do (setq lcm-denom (plcm lcm-denom (denom w))))
 ;	      (setq factor (cons lcm-denom gcd-num))
-;	      (setq answer (sloop for v in rat-fns
+;	      (setq answer (loop for v in rat-fns
 ;		    collecting (rattimes v factor t)))
 ;	      (setq header (list 'mrat 'simp varlist genvar))
-;	      (sloop for v in answer
+;	      (loop for v in answer
 ;		    collecting (ratdisrep (cons header v)) into tem
-;		    finally (return (cons '(mlist) tem))))))
-
+;		    finally (return (cons '(mlist) tem)))))
 
 (defun factoredp (poly)
   (cond ((atom poly) t)
-	(t (memq  'factored (car poly)))))
+	(t (member 'factored (car poly) :test #'eq))))
+
 (defun exponent (expr prod)
   (cond ((atom prod) 0)
 	((eq (caar prod) 'mexpt)(cond ((eq (second prod) expr)(third prod))
 				      (t 0)))
 	(t(check-arg prod '$productp nil)
-	 (sloop for v in (cdr prod)
-                 do
+	  (loop for v in (cdr prod) do
+	       (cond
+		 ((equal expr v) (return 1))
+		 ((numberp v))
+		 ((atom v))
+		 ((and (equal (caar v) 'mexpt)
+		       (equal (second v) expr))
+		  (return (third v))))
+	     finally (return 0)))))
 
-		 (cond 
-		       ((equal expr v) (return 1))
-		       ((numberp v))
-		       ((atom v))
-		       ((and (equal (caar v) 'mexpt)
-			     (equal (second v) expr))
-			     (return (third v))))
-		 finally (return 0)))))
-
-
-
- 
-		 
-(defun $projective (vector &aux factors first-one
-		    factored-vector expon lcm-denom tem fac where proj)
- (with-polynomial-area ()  
-  (setq factored-vector (sloop for v in (cdr vector)
-			      when (factoredp v) collecting v
-			      else collecting ($factor v)))
-  (sloop for v in factored-vector
-	for i from 0
-	when (not ($zerop v))
-	do (setq first-one v)(setq where i) (return 'done))
+(defun $projective (vector &aux factors first-one factored-vector expon lcm-denom tem fac where proj)
+  (setq factored-vector (loop for v in (cdr vector)
+			   when (factoredp v) collecting v
+			   else collecting ($factor v)))
+  (loop for v in factored-vector
+     for i from 0
+     when (not ($zerop v))
+     do (setq first-one v)(setq where i) (return 'done))
   (cond ((null where) 'image_not_in_projective_space)
 	(t
-	 (setq factored-vector (zl-delete first-one factored-vector 1))
-	 (setq proj (sloop for w in  factored-vector collecting (div* w first-one)))
-	 (sloop for term in proj
-	       when (not (numberp term) )
-	       do
-	       (cond ((atom term)(setq fac term))
-		     (t
-		      (sloop for v in (cdr term) do
-			    (cond ((atom v)(setq fac v))
-				  ((eq (caar v) 'mexpt)(setq fac (second v)))
-				  ((eq (caar v) 'mplus )(setq fac v)))
-			    (cond ((not (zl-member fac factors))(push fac factors)))))))
-	 (sloop for w in factors
-	       do (setq expon 0)
-	       (setq expon (sloop for v in proj
-				 
-				 when (< (setq tem (exponent w v)) 0)
-				 
-				 minimize tem))
-	       (cond ((not (eql expon 0))
-		      (push  `((mexpt simp) ,w ,expon) lcm-denom))))
+	 (setq factored-vector (delete first-one factored-vector :count 1 :test #'equal))
+	 (setq proj (loop for w in  factored-vector collecting (div* w first-one)))
+	 (loop for term in proj
+	    when (not (numberp term) )
+	    do
+	    (cond ((atom term)(setq fac term))
+		  (t
+		   (loop for v in (cdr term) do
+			(cond ((atom v) (setq fac v))
+			      ((eq (caar v) 'mexpt) (setq fac (second v)))
+			      ((eq (caar v) 'mplus) (setq fac v)))
+			(cond ((not (member fac factors :test #'equal)) (push fac factors)))))))
+	 (loop for w in factors
+	    do (setq expon 0)
+	    (setq expon (loop for v in proj
+			   when (< (setq tem (exponent w v)) 0)
+			   minimize tem))
+	    (cond ((not (eql expon 0))
+		   (push  `((mexpt simp) ,w ,expon) lcm-denom))))
 	 (cond (lcm-denom (push '(mtimes simp) lcm-denom))
 	       (t (setq lcm-denom 1)))
-	 
-	 
-	 (sloop for v in proj
-	       collecting (div* v lcm-denom) into tem
-	       finally (return
-			 
-			 (cons '(mlist)  (nsplice-in (f1- where)
-						     (div* 1 lcm-denom) tem))))))))
+	 (loop for v in proj
+	    collecting (div* v lcm-denom) into tem
+	    finally (return
+		      (cons '(mlist)  (nsplice-in (1- where)
+						  (div* 1 lcm-denom) tem)))))))
 (defun $zeta3_ratsimp (expr &aux answer)
   (setq answer (new-rat expr))
   (setq answer (rationalize-denom-zeta3 answer))
@@ -721,33 +514,27 @@ into genvar ordering and adds to genpairs"
 	   (variable-in-polyp1 (car r) gen)))))
 
 (defun $zeta3_factor (poly)
-  (with-polynomial-area (*genvar*)
-    ($factor poly `((mplus) ((mexpt) $%zeta3 2) $%zeta3 1)))) ; %zeta3^2+%zeta3+1
+  ($factor poly `((mplus) ((mexpt) $%zeta3 2) $%zeta3 1))) ; %zeta3^2+%zeta3+1
 
-(defun new-newvarmexpt (x e flag) 
+(defun new-newvarmexpt (x e flag)
   (declare (special radlist expsumsplit vlist))
        ;; when flag is t, call returns ratform
-       (prog (topexp) 
+       (prog (topexp)
 	     (cond ((and (fixp e) (not flag))
-		    (return (newvar1 (cadr x))))
-
-		   ;; this makes problems for risch ((and(not(fixp
-		   ;;e))(memq 'ratsimp (cdar x))) (return(setq vlist
-		   ;;(cons x vlist))))
-		   )
+		    (return (newvar1 (cadr x)))))
 	     (setq topexp 1)
 	top  (cond
 
 	      ;; x=b^n for n a number
 	      ((fixp e)
-	       (setq topexp (times topexp e))
+	       (setq topexp (* topexp e))
 	       (setq x (cadr x)))
 	      ((atom e) nil)
 
 	      ;; x=b^(p/q) for p and q integers
 	      ((eq (caar e) 'rat)
 	       (cond ((or (minusp (cadr e)) (greaterp (cadr e) 1))
-		      (setq topexp (times topexp (cadr e)))
+		      (setq topexp (* topexp (cadr e)))
 		      (setq x (list '(mexpt)
 				    (cadr x)
 				    (list '(rat) 1 (caddr e))))))
@@ -760,19 +547,19 @@ into genvar ordering and adds to genpairs"
 	      ;; x=b^(a*c)
 	      ((eq (caar e) 'mtimes)
 	       (cond
-		((or 
+		((or
 
 		     ;; x=b^(n *c)
 		     (and (atom (cadr e))
 			  (fixp (cadr e))
-			  (setq topexp (times topexp (cadr e)))
+			  (setq topexp (* topexp (cadr e)))
 			  (setq e (cddr e)))
 
 		     ;; x=b^(p/q *c)
 		     (and (not (atom (cadr e)))
 			  (eq (caaadr e) 'rat)
 			  (not (equal 1 (cadadr e)))
-			  (setq topexp (times topexp (cadadr e)))
+			  (setq topexp (* topexp (cadadr e)))
 			  (setq e (cons (list '(rat)
 					      1
 					      (caddr (cadr e)))
@@ -790,13 +577,13 @@ into genvar ordering and adds to genpairs"
 		x					;sums
 		(cons
 		 '(mtimes)
-		 (mapcar 
-		  (function (lambda (ll) 
-				    (list '(mexpt)
-					  (cadr x)
-					  (simplify (list '(mtimes)
-							   topexp
-							   ll)))))
+		 (mapcar
+		  #'(lambda (ll)
+		      (list '(mexpt)
+			    (cadr x)
+			    (simplify (list '(mtimes)
+					    topexp
+					    ll))))
 		  (cdr e))))
 	       (cond (flag (return (new-prep1 x)))
 		     (t (return (newvar1 x))))))
@@ -810,8 +597,7 @@ into genvar ordering and adds to genpairs"
 			  (t (cond ((or (atom x) (null *fnewvarsw))
 				    (putonvlist x))
 				   (t (setq x (littlefr1 x))
-				      (mapc (function newvar1)
-					    (cdr x))
+				      (mapc #'newvar1 (cdr x))
 				     (or (memalike x vlist)
 					 (memalike x varlist)
 					 (putonvlist x)))))))
@@ -831,19 +617,16 @@ into genvar ordering and adds to genpairs"
 	       (t (ratexpt (new-prep1 x) topexp))))))
 
 
-(defun new-newsym (e &aux #+lispm(working-storage-area default-cons-area))
+(defun new-newsym (e)
   (prog (g p)
 	(cond ((setq g (assolike e genpairs))
 	       (return g)))
-	#-lispm
 	(setq g (gensym))
-	#+lispm
-	(setq g (gensym-readable e))
 	(putprop g e 'disrep)
 	(add-newvar e)
 ;	(push e varlist)
 ;	(push (cons e (rget g)) genpairs)
-;	(valput g (if genvar (f1- (valget (car genvar))) 1))
+;	(valput g (if genvar (1- (valget (car genvar))) 1))
 ;	(push g genvar)
 	(cond ((setq p (and $algebraic (algpget e)))
 ;	       (algordset p genvar)
@@ -867,7 +650,5 @@ into genvar ordering and adds to genpairs"
   (do ((p (pt-red x) (pt-red p))) ((ptzerop p)) (setf (pt-lc p) (pdis (pt-lc p))))
   (setq algvar (cons algvar x))
   (if (setq x (assol (car algvar) tellratlist))
-      (setq tellratlist (zl-remove x tellratlist)))
+      (setq tellratlist (remove x tellratlist :test #'equal)))
   (push algvar tellratlist))
-
-
