@@ -1,7 +1,7 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;                                                                              
-;;;  $Id: grobner.lisp,v 1.3 2007/04/14 21:23:05 are_muc Exp $		 
+;;;  $Id: grobner.lisp,v 1.6 2009-06-02 07:49:49 andrejv Exp $		 
 ;;;  Copyright (C) 1999, 2002 Marek Rychlik <rychlik@u.arizona.edu>		 
 ;;;  		       								 
 ;;;  This program is free software; you can redistribute it and/or modify	 
@@ -28,10 +28,7 @@
     #+gcl (load eval)
     #-gcl (:load-toplevel :execute)
     (format t "~&Loading maxima-grobner ~a ~a~%"
-	    "$Revision: 1.3 $" "$Date: 2007/04/14 21:23:05 $"))
-
-;;FUNCTS is loaded because it contains the definition of LCM
-($load "functs")
+	    "$Revision: 1.6 $" "$Date: 2009-06-02 07:49:49 $"))
 
 ;; Macros for making lists with iterators - an exammple of GENSYM
 ;; MAKELIST-1 makes a list with one iterator, while MAKELIST accepts an
@@ -126,7 +123,7 @@
 INITIAL-CONTENTS specifies the list of powers of the consecutive
 variables. The alternative additional argument INITIAL-ELEMENT
 specifies the common power for all variables."
-  (declare (fixnum dim))
+  ;(declare (fixnum dim))
   `(make-array ,dim
 	       :element-type 'exponent
 	       ,@(when initial-contents-supplied-p `(:initial-contents ,initial-contents))
@@ -549,7 +546,6 @@ Top reduction means that division algorithm stops after the first reduction.")
 
 (defstruct (term
 	    (:constructor make-term (monom coeff))
-	    (:constructor make-term-variable)
 	    ;;(:type list)
 	    )
   (monom (make-monom 0) :type monom)
@@ -627,7 +623,7 @@ in the coefficient ring."
 (defun monom-times-term (m term)
   (make-term (monom-mul m (term-monom term)) (term-coeff term)))
 
-(declaim (ftype (function (monom list) list) monom-times-poly))
+(declaim (ftype (function (monom list) list) monom-times-termlist))
 
 (defun monom-times-termlist (m f)
   (cond
@@ -1950,14 +1946,14 @@ polynomials in the list IDEAL-LIST."
 		      (t
 		       (case (caar expr)
 			 (mrat (eql ($ratdisrep expr) 0))
-			 (otherwise (eql ($totaldisrep expr) 0))))))
-     :add #'(lambda (x y) (m+ x y))
-     :sub #'(lambda (x y) (m- x y))
+			 (otherwise (eql (sratsimp expr) 0))))))
+     :add #'(lambda (x y) (sratsimp (m+ x y)))
+     :sub #'(lambda (x y) (sratsimp (m- x y)))
      :uminus #'(lambda (x) (m- x))
      :mul #'(lambda (x y) (m* x y))
      ;;(defun coeff-div (x y) (cadr ($divide x y)))
-     :div #'(lambda (x y) (m// x y))
-     :lcm #'(lambda (x y) (meval1 `((|$lcm|) ,x ,y)))
+     :div #'(lambda (x y) (sratsimp (m// x y)))
+     :lcm #'(lambda (x y) (sratsimp (m// (m* x y) (second ($ezgcd x y)))))
      :ezgcd #'(lambda (x y) (apply #'values (cdr ($ezgcd x y))))
      :gcd #'(lambda (x y) (second ($ezgcd x y)))))
 
@@ -1983,9 +1979,13 @@ are assumed to be defined.")
 
 (defun free-of-vars (expr vars) (apply #'$freeof `(,@vars ,expr)))
 
-(defun parse-poly (expr vars &aux (vars (coerce-maxima-list vars)))
+;; This function removes rational numbers from coefficients of polynomials.
+(defun parse-poly (expr vars)
+  (parse-poly1 ($num (sratsimp expr)) vars))
+
+(defun parse-poly1 (expr vars &aux (vars (coerce-maxima-list vars)))
   "Convert a maxima polynomial expression EXPR in variables VARS to internal form."
-  (labels ((parse (arg) (parse-poly arg vars))
+  (labels ((parse (arg) (parse-poly1 arg vars))
 	   (parse-list (args) (mapcar #'parse args)))
     (cond
      ((eql expr 0) (make-poly-zero))
