@@ -1,6 +1,3 @@
-
-
-
 ;*******************************************************************************
 ;*                                                                             *
 ;*  copyright (c) 1988 kent state univ.  kent, ohio 44242                      *
@@ -15,6 +12,7 @@
 	*lisplogexpops* *lispstmtops* *lispstmtgpops*))
 
 (declare-top (special *gendecs *endofloopstack* fortcurrind* tablen*))
+
 ;;  -----------  ;;
 ;;  lspfor.l     ;;    lisp-to-fortran translation module
 ;;  -----------  ;;
@@ -24,13 +22,18 @@
 (put 'not      '*fortranprecedence* 3)
 (put 'equal    '*fortranprecedence* 4)
 (put 'notequal '*fortranprecedence* 4)
+(put '>        '*fortranprecedence* 4)
 (put 'greaterp '*fortranprecedence* 4)
 (put 'geqp     '*fortranprecedence* 4)
+(put '<        '*fortranprecedence* 4)
 (put 'lessp    '*fortranprecedence* 4)
 (put 'leqp     '*fortranprecedence* 4)
+(put '+        '*fortranprecedence* 5)
 (put 'plus     '*fortranprecedence* 5)
+(put '*        '*fortranprecedence* 6)
 (put 'times    '*fortranprecedence* 6)
 (put 'quotient '*fortranprecedence* 6)
+(put '-        '*fortranprecedence* 7)
 (put 'minus    '*fortranprecedence* 7)
 (put 'expt     '*fortranprecedence* 8)
 (put 'or       '*fortranop* '| .or. |)
@@ -38,14 +41,19 @@
 (put 'not      '*fortranop* '| .not. |)
 (put 'equal    '*fortranop* '| .eq. |)
 (put 'notequal '*fortranop* '| .ne. |)
+(put '>        '*fortranop* '| .gt. |)
 (put 'greaterp '*fortranop* '| .gt. |)
 (put 'geqp     '*fortranop* '| .ge. |)
+(put '<        '*fortranop* '| .lt. |)
 (put 'lessp    '*fortranop* '| .lt. |)
 (put 'leqp     '*fortranop* '| .le. |)
+(put '+        '*fortranop* '|+|)
 (put 'plus     '*fortranop* '|+|)
+(put '*        '*fortranop* '|*|)
 (put 'times    '*fortranop* '|*|)
 (put 'quotient '*fortranop* '|//|)
 (put 'expt     '*fortranop* '|**|)
+(put '-        '*fortranop* '|-|)
 (put 'minus    '*fortranop* '|-|)
 (put nil '*fortranname* ".false.")
 
@@ -137,13 +145,13 @@
 	((eq (car exp) 'data) (fortdata exp))
 	((eq (car exp) 'literal) (fortliteral exp))
 	((null (cdr exp)) exp)
-	((memq (car exp) '(minus not))
+	((member (car exp) '(minus not) :test #'eq)
 	 (let* ((wt (fortranprecedence (car exp)))
 		(res (cons (fortranop (car exp)) (fortexp1 (cadr exp) wt))))
 	       (cond ((< wt wtin) (aconc (cons '|(| res) '|)|))
 		     (t res))))
-	((or (memq (car exp) *lisparithexpops*)
-	     (memq (car exp) *lisplogexpops*))
+	((or (member (car exp) *lisparithexpops* :test #'eq)
+	     (member (car exp) *lisplogexpops* :test #'eq))
 	 (let* ((wt (fortranprecedence (car exp)))
 		(op (fortranop (car exp)))
 		(res (fortexp1 (cadr exp) wt))
@@ -225,13 +233,12 @@
   (prog (n1 hi incr result)
 	(setq n1 (genstmtno))
 	(setq *endofloopstack* (cons n1 *endofloopstack*))
-	(setq hi (car (delete1 'greaterp
-			       (delete1 'lessp (delete1 var exitcond)))))
+	(setq hi (car (delete1 '> (delete1 '< (delete1 var exitcond)))))
 	(setq incr (car (delete1 'plus (delete1 var nextexp))))
 	(setq result (mkffortdo n1 var lo hi incr))
 	(indentfortlevel (+ 1))
 	(setq result (append result (foreach st in body conc (fortstmt st))))
-	(indentfortlevel (minus 1))
+	(indentfortlevel (- 1))
 	(setq result (append result (mkffortcontinue n1)))
 	(cond ((listp (car *endofloopstack*))
 	       (setq result
@@ -262,7 +269,7 @@
 		(cond ((equal nextexp '(nil)) (setq nextexp nil)))
 		(setq result (append result (mkffortassign var nextexp))))))
 	(setq result (append result (mkffortgo n1)))
-	(indentfortlevel (minus 1))
+	(indentfortlevel (- 1))
 	(setq result (append result (mkffortcontinue n2)))
 	(cond ((listp (car *endofloopstack*))
 	       (setq result
@@ -292,7 +299,7 @@
 			(indentfortlevel (+ 1))
 			(setq res (append res (foreach st in (cdar stmt) conc
 						       (fortstmt st))))
-			(indentfortlevel (minus 1))
+			(indentfortlevel (- 1))
 			(append res (mkffortcontinue n1)))))))
 	      (t
 	       (return
@@ -304,11 +311,11 @@
 		 (setq res (append res (foreach st in (cdar stmt) conc
 						(fortstmt st))))
 		 (setq res (append res (mkffortgo n2)))
-		 (indentfortlevel (minus 1))
+		 (indentfortlevel (- 1))
 		 (setq res (append res (mkffortcontinue n1)))
 		 (indentfortlevel (+ 1))
 		 (setq res (append res (fortif (cons 'cond (cdr stmt)))))
-		 (indentfortlevel (minus 1))
+		 (indentfortlevel (- 1))
 		 (append res (mkffortcontinue n2))))))))
 
 (defun fortliteral (stmt)
@@ -351,7 +358,7 @@
 		    lo
 		    (equal (car nextexp) 'plus)
 		    (member var nextexp)
-		    (member (car exitcond) '(greaterp lessp))
+		    (member (car exitcond) '(> <))
 		    (member var exitcond))
 	       (return (fortdo var lo nextexp exitcond body)))
 	      ((and exitcond
@@ -375,7 +382,7 @@
 	(setq result (mkffortcontinue n))
 	(indentfortlevel (+ 1))
 	(setq result (append result (foreach st in body conc (fortstmt st))))
-	(indentfortlevel (minus 1))
+	(indentfortlevel (- 1))
 	(setq result (append result (mkffortifgo (list 'not exitcond) n)))
 	(cond ((listp (car *endofloopstack*))
 	       (setq result
@@ -387,7 +394,7 @@
 (defun fortreturn (stmt)
   (cond ((onep (length stmt))
 	 (mkffortreturn))
-	((neq (car *symboltable*) '*main*)
+	((not (eq (car *symboltable*) '*main*))
 	 (append (mkffortassign (car *symboltable*) (cadr stmt))
 		 (mkffortreturn)))
 	(t
@@ -422,7 +429,7 @@
 	(indentfortlevel (+ 1))
 	(setq result (append result (foreach st in body conc (fortstmt st))))
 	(setq result (append result (mkffortgo n1)))
-	(indentfortlevel (minus 1))
+	(indentfortlevel (- 1))
 	(setq result (append result (mkffortcontinue n2)))
 	(cond ((listp (car *endofloopstack*))
 	       (setq result
