@@ -2,13 +2,15 @@
 
 #+nil
 (progn
-  (format t "path = ~A~%" (combine-path (list *maxima-sharedir* "lapack")))
+  (format t "path = ~A~%" (combine-path *maxima-sharedir* "lapack"))
   (format t "*load-truename* = ~A~%" *load-truename*)
   (format t "sys = ~A~%" (merge-pathnames (make-pathname :name "lapack" :type "system")
 					  *load-truename*)))
 
+#+ecl ($load "lisp-utils/defsystem.lisp")
 
 (load (merge-pathnames (make-pathname :name "lapack" :type "system")
 		       #-gcl *load-pathname*
 		       #+gcl sys:*load-pathname*))
+
 (mk:oos "lapack-interface" :compile)
