@@ -2,16 +2,13 @@
 
 (defvar *info-tables* (make-hash-table :test 'equal))
 
-(defvar *prompt-prefix* "")
-(defvar *prompt-suffix* "")
-
 (defun print-prompt (prompt-count)
-  (format t "~&~a~a~a"
-	  *prompt-prefix*
-	  (if (zerop prompt-count)
+  (fresh-line)
+  (maxima::format-prompt
+   t "~a"
+   (if (zerop prompt-count)
 	      (intl:gettext "Enter space-separated numbers, `all' or `none': ")
-	      (intl:gettext "Still waiting: "))
-	  *prompt-suffix*))
+	      (intl:gettext "Still waiting: "))))
 
 (defvar +select-by-keyword-alist+
   '((noop "") (all "a" "al" "all") (none "n" "no" "non" "none")))
