@@ -330,12 +330,12 @@
 	   ((equal e '(0 . 1))
 	    (setq c 0)
 	    (go loop)))
-     (setq c (pterm (cdar e) 1))
+     (setq c (ptterm (cdar e) 1))
      loop (cond ((atom c)
 		 (cond ((equal c 0) (return nil))
 		       ((equal 1 d) (return c))
 		       (t (return (list '(rat) c d))))))
-     (setq c (pterm (cdr c) 0))
+     (setq c (ptterm (cdr c) 0))
      (go loop)))
 
 (defun spang1 (j ind)
