@@ -526,31 +526,34 @@
 
 (defun set-intersect (l1 l2)
   ;;  Only works for lists of sorted by $orderlessp.
-  (do-merge-symm
-   l1 l2
-   #'like
-   #'$orderlessp
-   #'(lambda (x) (push x res))
-   nil))
+  (with-collector collect
+    (do-merge-symm
+        l1 l2
+        #'like
+        #'$orderlessp
+        #'collect
+        nil)))
 
 (defun set-union (l1 l2)
   ;; Only works for lists of sorted by $orderlessp.
-  (do-merge-symm
-   l1 l2
-   #'like
-   #'$orderlessp
-   #'(lambda (x) (push x res))
-   #'(lambda (x) (push x res))))
+  (with-collector collect
+    (do-merge-symm
+        l1 l2
+        #'like
+        #'$orderlessp
+        #'collect
+        #'collect)))
 
 (defun sset-difference (l1 l2)
   ;; Only works for lists of sorted by $orderlessp.
-  (do-merge-asym
-   l1 l2
-   #'like
-   #'$orderlessp
-   nil
-   #'(lambda (x) (push x res))
-   nil))
+  (with-collector collect
+    (do-merge-asym
+        l1 l2
+        #'like
+        #'$orderlessp
+        nil
+        #'collect
+        nil)))
 
 (defun set-subsetp (l1 l2)
   ;; Is l1 a subset of l2
@@ -565,12 +568,13 @@
     t))
 
 (defun set-symmetric-difference (l1 l2)	; i.e. xor
-  (do-merge-symm
-   l1 l2
-   #'like
-   #'$orderlessp
-   nil
-   #'(lambda (x) (push x res))))
+  (with-collector collect
+    (do-merge-symm
+        l1 l2
+        #'like
+        #'$orderlessp
+        nil
+        #'collect)))
 	
 (defun set-disjointp (l1 l2)
   (catch 'disjoint
@@ -863,7 +867,7 @@
 (setf (get '%kron_delta 'verb) '$kron_delta)
 (setf (get '$kron_delta 'alias) '%kron_delta)
 (setf (get '%kron_delta 'reversealias) '$kron_delta)
-(defun $kron_delta (x) (take '($kron_delta) x))
+(defun $kron_delta (&rest x) (simplifya `((%kron_delta) ,@x) t))
 (setf (get '%kron_delta 'real-valued) t) ;; conjugate(kron_delta(xxx)) --> kron_delta(xxx)
 (setf (get '%kron_delta 'integer-valued) t) ;; featurep(kron_delta(xxx), integer) --> true
 
@@ -873,7 +877,7 @@
   (declare (ignore y))
 
   (setq l (cdr l)) ;; remove (($kron_delta simp)
-  (if (and l (null (cdr l))) (wna-err '$knon_delta)) ;; wrong number of arguments error for exactly one argument
+  (if (and l (null (cdr l))) (wna-err '$kron_delta)) ;; wrong number of arguments error for exactly one argument
 
   ;; Checking both mnqp and meqp is convenient, but unnecessary. This code misses simplifications that
   ;; involve three or more arguments. Example: kron_delta(a,b,a+b+1,a-b+5) could (but doesn't) simplify 
@@ -1113,6 +1117,7 @@
 (def-nary '$max (s) (if (null s) '$minf (maximin s '$max)) '$minf)
 (def-nary '$min (s) (if (null s) '$inf (maximin s '$min)) '$inf)
 (def-nary '$append (s) (xappend s) '((mlist)))
+(def-nary '$union (s) ($apply '$union (cons '(mlist) s)) '(($set)))
 
 ;; Extend a function f : S x S -> S to n arguments. When we 
 ;; recognize f as a nary function (associative), if possible we call a Maxima
@@ -1294,14 +1299,19 @@
    ;; NOT CLEAR FROM PRECEDING CODE WHAT IS "INVALID" HERE
    (merror (intl:gettext "some: invalid arguments.")))))
 
-(defun $makeset (f v s)
-  (if (or (not ($listp v)) 
-	  (not (every #'(lambda (x) (or ($atom x) ($subvarp x))) (cdr v))))
-      (merror (intl:gettext "makeset: second argument must be a list of atoms or subscripted variables; found: ~:M") v))
-  (setq s (require-list-or-set s "$makeset"))
-
-  (setq f `((lambda) ,v ,f))
-  `(($set) ,@(mapcar #'(lambda (x) (mfuncall '$apply f x)) s)))
+(defmspec $makeset (l)
+  (let* ((fn (car (pop l)))
+	 (f (if l (pop l) (wna-err fn)))
+	 (v (if l (pop l) (wna-err fn)))
+	 (s (if l (pop l) (wna-err fn))))
+    (if l (wna-err fn))
+    (if (or (not ($listp v)) (not (every #'(lambda (x) (or ($symbolp x) ($subvarp x))) (cdr v))))
+   	(merror (intl:gettext "makeset: second argument must be a list of symbols; found: ~:M") v))
+    (setq s (require-list-or-set (meval s) "$makeset"))
+    (setq f (list (list 'lambda) v f))
+    (setq v (margs v))
+    (dolist (sk v) (setq f (subst (gensym) sk f :test #'alike1)))
+    (simplifya (cons '($set) (mapcar #'(lambda (x) (mfuncall '$apply f x)) s)) t)))
 
 ;; Thread fn over l and apply op to the resulting list.
 
