@@ -45,7 +45,7 @@
 
 (defmfun $pade (taylor-form n-bound d-bound)
   (cond ((not (and ($ratp taylor-form) (member 'trunc (car taylor-form) :test #'eq)))
-	 (merror "First argument to Pade must be a taylor series")))
+	 (merror (intl:gettext "pade: first argument must be a Taylor series; found: ~M") taylor-form)))
   (destructuring-let (((nil nil varlist genvar tlist) (car taylor-form)))
     (if (psp (cdr taylor-form))		     
 	(cons '(mlist)
