@@ -16,19 +16,17 @@
 
 (load-macsyma-macros ratmac)
 
-(declare-top(splitfile mresul))
-
 (defmfun $poly_discriminant (poly var)
   (let* ((varlist (list var))
 	 ($ratfac nil)
-	 (genvar ()) 
+	 (genvar ())
 	 (rform (rform poly))
 	 (rvar (car (last genvar)))
 	 (n (pdegree (setq poly (car rform)) rvar)))
-	
+
     (cond ((= n 1) 1)
 	  ((or (= n 0) (not (atom  (cdr rform))))
-	   (merror "The first argument to 'poly_discriminant' must be a polynomial in ~:M" var))
+	   (merror (intl:gettext "poly_discriminant: first argument must be a polynomial in ~:M; found: ~M") var poly))
 	  (t (pdis (presign
 		    (ash (* n (1- n)) -1)
 		    (pquotient (resultant poly (pderivative poly rvar))
@@ -47,7 +45,7 @@
      (do ((l1 a (cdr l1))) ((null l1))
        (do ((l2 b (cdr l2))) ((null l2))
 	 (setq res (result1 (caar l1) (caar l2) mainvar))
-	 (setq ans (ptimes ans (pexpt 
+	 (setq ans (ptimes ans (pexpt
 				(cond ((zerop (caddr res)) (car res))
 				      (t (ptimeschk (car res)
 						    (pexpt (makprod (cadr res) nil)
@@ -80,12 +78,12 @@
 
 (defmfun resultant (p1 p2)		;assumes same main var
   (if (> (p-le p2) (p-le p1))
-      (presign (* (p-le p1) (p-le p2)) (resultant p2 p1)) 
+      (presign (* (p-le p1) (p-le p2)) (resultant p2 p1))
       (case $resultant
 	($subres (subresult p1 p2))
 	#+broken ($mod (modresult p1 p2))
 	($red (redresult p1 p2))
-	(t (merror "No such resultant algorithm")))))
+	(t (merror (intl:gettext "resultant: no such algorithm: ~M") $resultant)))))
 
 (defun presign (n p)
   (if (oddp n) (pminus p) p))
@@ -103,7 +101,7 @@
 		   q (presign (1+ d) (pquotient (prem p q)
 						 (ptimes g (ptimes h h^1-d)))))))
 
-;;	PACKAGE FOR CALCULATING MULTIVARIATE POLYNOMIAL RESULTANTS 
+;;	PACKAGE FOR CALCULATING MULTIVARIATE POLYNOMIAL RESULTANTS
 ;;	USING MODIFIED REDUCED P.R.S.
 
 (defun redresult (u v)
@@ -127,7 +125,7 @@
      (go a)))
 
 
-;;	PACKAGE FOR CALCULATING MULTIVARIATE POLYNOMIAL RESULTANTS 
+;;	PACKAGE FOR CALCULATING MULTIVARIATE POLYNOMIAL RESULTANTS
 ;;	USING MODULAR AND EVALUATION HOMOMORPHISMS.
 ;; modresultant fails on the following example
 ;;RESULTANT(((-4)*Z)^4+(Y+8*Z)^4+(X-5*Z)^4-1,
@@ -145,7 +143,7 @@
 	  (t (cpres x y (car varl) (cdr varl))) ))
 
   (defun pres (a b xr1 varl)
-    (prog (m n f a* b* c* p q c modulus hmodulus)
+    (prog (m n f a* b* c* p q c modulus)
        (setq m (cadr a))
        (setq n (cadr b))
        (setq f (coefbound m n (maxnorm (cdr a)) (maxnorm (cdr b)) ))
@@ -154,12 +152,12 @@
        (setq p *alpha)
        (go step3)
        step2	(setq p (newprime p))
-       step3	(setqmodulus p)
+       step3	(set-modulus p)
        (setq a* (pmod a))
        (setq b* (pmod b))
        (cond ((or (reject a* m xr1) (reject b* n xr1)) (go step2)))
        (setq c* (cpres a* b* xr1 varl))
-       (setqmodulus nil)
+       (set-modulus nil)
        (setq c (lagrange3 c c* p q))
        (setq q (* p q))
        (cond ((> q f) (return c))
@@ -208,7 +206,7 @@
 		   (setq bp (- 1))
 		   step3
 		   (cond ((equal (setq bp (1+ bp)) modulus)
-			  (merror "Resultant primes too small."))
+			  (merror "CPRES: resultant primes too small."))
 			 ((zerop m2) (setq a* a))
 			 (t (setq a* (pcsubst a bp xv))
 			    (cond ((reject a* m1 xr1)(go step3)) )) )
@@ -252,7 +250,7 @@
 	 (b (vmake (p-terms q) n nil))
 	 (ar (reverse (nthcdr n2 a)))
 	 (br (reverse (nthcdr n2 b)))
-	 (l (nzeros n nil)))
+	 (l (make-list n :initial-element 0)))
     (rplacd (nthcdr (1- (p-le p)) a) nil)
     (rplacd (nthcdr (1- (p-le p)) b) nil)
     (nconc
