@@ -16,8 +16,6 @@
 
 ;; TOP LEVEL FUNCTION(S): $TLIMIT $TLDEFINT
 
-(declare-top (special exp var val ll ul))
-
 (defmfun $tlimit (&rest args)
   (let ((limit-using-taylor t))
     (declare (special limit-using-taylor))
@@ -31,27 +29,25 @@
 (defun tlimp (exp)		; TO BE EXPANDED TO BE SMARTER (MAYBE)
   t)
 
-;; compute limit of e by finding its taylor series expansion.
+;; compute limit of exp by finding its taylor series expansion.
 ;; asks for $lhospitallim terms of taylor series.
 ;; this is an arbitrary limit: with default value $lhospitallim = 4,
 ;;  tlimit(2^n/n^5, n, inf)  =>  0
-(defun taylim (e *i*)
+(defun taylim (exp var val *i*)
   (prog (ex)
      (setq ex (catch 'taylor-catch
 		(let ((silent-taylor-flag t))
 		  (declare (special silent-taylor-flag))
-		  ($taylor e var (ridofab val) $lhospitallim))))
+		  ($taylor exp var (ridofab val) $lhospitallim))))
      (or ex (return (cond ((eq *i* t)
-			   (limit1 e var val))
+			   (limit1 exp var val))
 			  ((eq *i* 'think)
 			   (if (member (caar exp) '(mtimes mexpt) :test #'eq)
-			       (limit1 e var val)
-			       (simplimit e var val)))
+			       (limit1 exp var val)
+			       (simplimit exp var val)))
 			  (t
-			   (simplimit e var val)))))
+			   (simplimit exp var val)))))
      (return
        (let ((taylored t))
 	 (declare (special taylored))
 	 (limit (simplify ($ratdisrep ex)) var val 'think)))))
-
-(declare-top (unspecial exp var val ll ul))
