@@ -17,8 +17,6 @@
 
 (macsyma-module trans1)
 
-(transl-module trans1)
-
 ;;;;;;;; THE FOLLOWING ARE MOSTLY FROM JPG MLISP ;;;;;;;;;;;;;;;;;;;;;
 
 ;;; APPLY(F,[X]) is an idiom for funcall.
@@ -294,12 +292,7 @@
      '($any . '$**error**))))
 
 (def%tr $kill (form)
-  (cond ($tr_windy
-	 (tr-tell "
-Warning:" form
-"Use of KILL in translated program is not recommended. See GJC for
-a replacement form. Translating anyway though.")))
-  `($any . (apply '$kill ',(cdr form))))
+  `($any . (mapply '$kill ',(cdr form) nil)))
 
 ;;; Macsyma arrays are the biggest crock since STATUS PUNT NIL days.
 ;;; The basic idea of ARRAY(<frob>,type,dims...) is that
@@ -394,7 +387,6 @@ a replacement form. Translating anyway though.")))
 (def%tr $loadfile $batcon)
 (def%tr $loadarrays         $batcon)
 (def%tr $loadplots $batcon)
-(def%tr $makeatomic $batcon)
 (def%tr $namefile $batcon)
 (def%tr $numerval           $batcon)
 (def%tr $options $batcon)
