@@ -19,8 +19,6 @@
 ;;; Since it is so small, and compiles so quickly it sometimes serves
 ;;; as a fix (i.e. hack) file. so be careful.
 
-(transl-module trdata)
-
 ;;; MODEDECLARE(FUNCTION(LENGTH),FIXNUM)
 
 ;;I think all this can be done at load time only:--wfs
@@ -54,11 +52,6 @@
 	    $scalarmatrix $simp $ttyoff $underflow $infeval
 	    $xaxis $yaxis $ratfac))
 
-    (mapc #'(lambda (x) (putprop x (stripdollar x) 'lisp-function-to-use))
-	  '(%log %sin %cos %tan %cot %csc %sec %acot
-	    %asin %acos %acsc %asec
-	    %sinh %cosh %tanh %coth %csch %sech %asinh %acsch %erf))
-
     (mapc #'(lambda (x) (putprop x t 'implied-quotep))
 	  '($eval $done $%i $%pi $%e $%phi $%gamma
 	    mqapply	; important for array referencing conventions.
@@ -79,29 +72,4 @@
 	  '($print $num $denom $lhs $rhs $part
 	    $cons $reverse $endcons $append
 	    $union $intersection $setdiff $symdiff
-	    $mapset $predset |${| $elementof))
-
-    (defprop $realpart $realpart lisp-function-to-use)
-
-
-    (setq transl-modules '(transs
-			   transl
-			   trutil
-			   trans1
-			   trans2
-			   trans3
-			   trans4
-			   trans5
-			   transf
-			   troper
-			   trpred
-
-			   mtags
-			   mdefun
-			   transq
-			   fcall
-			   acall
-			   trdata
-			   mcompi
-			   trmode
-			   trhook)))
+	    $mapset $predset |${| $elementof)))
